@@ -10,12 +10,15 @@
 #include "../libpcsxcore/psemu_plugin_defs.h"
 #include "common/readpng.h"
 #include "maemo_common.h"
+#include <libosso.h>
+#include <dbus/dbus.h>
 
 #define X_RES           800
 #define Y_RES           480
 #define D_WIDTH			640
 #define D_HEIGHT		480
 
+osso_context_t* osso;
 int g_layer_x = (X_RES - D_WIDTH) / 2;
 int g_layer_y = (Y_RES - D_HEIGHT) / 2;
 int g_layer_w = D_WIDTH, g_layer_h = D_HEIGHT;
@@ -60,6 +63,25 @@ window_key_proxy(GtkWidget *widget,
 	return key_press_event(event->hardware_keycode, event->type == GDK_KEY_PRESS?1:(event->type == GDK_KEY_RELEASE?2:0) );
 }
 
+void show_notification(char* text)
+{
+	DBusConnection* session_bus = (DBusConnection*)osso_get_dbus_connection(osso);
+	DBusMessageIter args;
+	DBusMessage*msg = dbus_message_new_method_call("org.freedesktop.Notifications", 
+												   "/org/freedesktop/Notifications",
+												   "org.freedesktop.Notifications", 
+												   "SystemNoteInfoprint");
+	if (msg) { 
+		dbus_message_iter_init_append(msg, &args);
+		char* param = text;
+		if (dbus_message_iter_append_basic(&args, DBUS_TYPE_STRING, &param)) {
+			dbus_connection_send(session_bus, msg, NULL);
+			dbus_connection_flush(session_bus);
+		}
+		dbus_message_unref(msg);
+	}
+}
+
 inline void key_press_event(int key2,int type)
 {
 	int  psxkey1 = -1, psxkey2 = -1;
@@ -100,6 +122,9 @@ inline void key_press_event(int key2,int type)
                     sprintf (buf,"/opt/maemo/usr/games/screenshots%s.%3.3d",file_name,state_slot);
                     writepng(buf, image->mem, pl_buf_w,pl_buf_h);
 				}
+				char message[50];
+				sprintf(message,"Saved savestate slot: %i",state_slot);
+				show_notification(message);
 			}
 			return;
 		case 20:
@@ -107,12 +132,22 @@ inline void key_press_event(int key2,int type)
 				emu_load_state(state_slot);
 			return;
 		case 21:
-			if (type == 1)
+			if (type == 1){
 				state_slot=(state_slot<9)?state_slot+1:0;
+				char message[50];
+				sprintf(message,"Savestate slot: %i",state_slot);
+				printf("%s\n", message);
+				show_notification(message);
+			}
 			return;
 		case 22:
-			if (type == 1)
-				state_slot=(state_slot>0)?state_slot-1:8;
+			if (type == 1){
+				state_slot=(state_slot>0)?state_slot-1:9;
+				char message[50];
+				sprintf (message,"Savestate slot: %i",state_slot);
+				printf("%s\n", message);
+				show_notification(message);
+			}
 			return;
 	}
 
@@ -139,6 +174,8 @@ void plat_finish()
 
 void maemo_init(int *argc, char ***argv)
 {
+	osso = osso_initialize("pcsxrearmed", PACKAGE_VERSION, FALSE, NULL);
+
 	FILE* pFile;
 	pFile = fopen("/opt/psx4m/keys", "r"); // assume the file exists and has data
 	int ch;
@@ -146,7 +183,7 @@ void maemo_init(int *argc, char ***argv)
 	for (i=0;i<65536;i++)
 		keymap[i]=164;
 	if (NULL != pFile) {
-		for(i=0;i<21;i++){
+		for(i=0;i<23;i++){
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
 		}
