@@ -103,25 +103,32 @@ void PrintHelp()
 	printf("                          2=Auto (Default)\n");
 */
 
-/*
 	printf("\nGles Options:\n");
 	printf("  -gles_dithering VALUE : Enable/disable dithering [0/1]\n");
+    printf("                          (Default disabled)\n");
 	printf("  -gles_mask VALUE      : Enable/disable mask detect [0/1]\n");
+    printf("                          (Default disabled)\n");
 	printf("  -gles_filtering VALUE : Texture Filtering\n");
-	printf("                          0=None\n");
+	printf("                          0=None (Default)\n");
 	printf("                          1=Standard\n");
 	printf("                          2=Extended\n");
 	printf("                          3=Standard-sprites\n");
 	printf("                          4=Extended-sprites\n");
 	printf("                          5=Standard+sprites\n");
-	printf("                          6=Extended+sprites]\n");
+	printf("                          6=Extended+sprites\n");
 	printf("  -gles_fbtex VALUE     : Framebuffer Textures\n");
-	printf("                          0=Emulated VRam\n");
+	printf("                          0=Emulated VRam (Default)\n");
 	printf("                          1=Black\n");
 	printf("                          2=Card\n");
 	printf("                          3=Card+soft\n");
 	printf("  -gles_vram VALUE      : Texture RAM size in MB [4-128]\n");
-*/
+    printf("                          (Default 64)\n");
+    printf("  -gles_fastmdec VALUE  : Enable/disable Fast Mdec [0/1]\n");
+    printf("                          (Default disabled)\n");
+    printf("  -gles_advblend VALUE  : Enable/disable Adv. Blend [0/1]\n");
+    printf("                          (Default disabled)\n");
+    printf("  -gles_opaque VALUE    : Enable/disable Opaque Pass [0/1]\n");
+    printf("                          (Default disabled)\n");
 }
 
 int maemo_main(int argc, char **argv)
@@ -182,9 +189,9 @@ int maemo_main(int argc, char **argv)
 				Config.PsxType = psx_reg;
 			}
 		}
-		else if (!strcmp(argv[i], "-fullscreen"))	        { g_maemo_opts |= 2; pl_rearmed_cbs.gpu_peopsgl.bKeepRatio = 0; }
+		else if (!strcmp(argv[i], "-fullscreen"))	        { g_maemo_opts |= 2; pl_rearmed_cbs.gpu_peopsgl.bKeepRatio = FALSE; }
 		else if (!strcmp(argv[i], "-accel"))				g_maemo_opts |= 4;
-		else if (!strcmp(argv[i], "-sputhreaded"))		    iUseTimer=1;
+		else if (!strcmp(argv[i], "-sputhreaded"))		    iUseTimer=0;
 		else if (!strcmp(argv[i], "-nosound"))		        strcpy(Config.Spu, "spunull.so");
 		else if (!strcmp(argv[i], "-bdir"))			        sprintf(Config.BiosDir, "%s", argv[++i]);
 		else if (!strcmp(argv[i], "-pdir"))			        sprintf(Config.PluginsDir, "%s", argv[++i]);
@@ -212,13 +219,14 @@ int maemo_main(int argc, char **argv)
 		else if (!strcmp(argv[i], "-neon_interlace")) 	pl_rearmed_cbs.gpu_neon.allow_interlace = atol(argv[++i]);
 */
 
-/*
 		else if (!strcmp(argv[i], "-gles_dithering")) 	pl_rearmed_cbs.gpu_peopsgl.bDrawDither = atol(argv[++i]);
-		else if (!strcmp(argv[i], "-gles_mask")) 	pl_rearmed_cbs.gpu_peopsgl.iUseMask = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_mask")) 	    pl_rearmed_cbs.gpu_peopsgl.iUseMask = atol(argv[++i]);
 		else if (!strcmp(argv[i], "-gles_filtering")) 	pl_rearmed_cbs.gpu_peopsgl.iFilterType = atol(argv[++i]);
-		else if (!strcmp(argv[i], "-gles_fbtex")) 	pl_rearmed_cbs.gpu_peopsgl.iFrameTexType = atol(argv[++i]);
-		else if (!strcmp(argv[i], "-gles_vram")) 	pl_rearmed_cbs.gpu_peopsgl.iVRamSize = atol(argv[++i]);
-*/
+		else if (!strcmp(argv[i], "-gles_fbtex")) 	    pl_rearmed_cbs.gpu_peopsgl.iFrameTexType = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_vram")) 	    pl_rearmed_cbs.gpu_peopsgl.iVRamSize = atol(argv[++i]);
+		else if (!strcmp(argv[i], "-gles_fastmdec")) 	pl_rearmed_cbs.gpu_peopsgl.bUseFastMdec = atol(argv[++i]);
+        else if (!strcmp(argv[i], "-gles_advblend")) 	pl_rearmed_cbs.gpu_peopsgl.bAdvancedBlend = atol(argv[++i]);
+        else if (!strcmp(argv[i], "-gles_opaque")) 	    pl_rearmed_cbs.gpu_peopsgl.bOpaquePass = atol(argv[++i]);
 	}
 
 	hildon_init(&argc, &argv);
